/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-22 15:27:24.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.core.print.common.jpa.SearchBuilder;
import cn.com.qmth.examcloud.core.print.common.jpa.SpecUtils;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.CoursePaper;
import cn.com.qmth.examcloud.core.print.repository.CoursePaperRepository;
import cn.com.qmth.examcloud.core.print.service.CoursePaperService;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperConvert;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperInfo;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperQuery;
import cn.com.qmth.examcloud.core.print.service.bean.coursepaper.CoursePaperTotalInfo;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.List;

/**
 * @author: fengdesheng
 * @since: 2018/10/17
 */
@Service
public class CoursePaperServiceImpl implements CoursePaperService {
    private static final Logger log = LoggerFactory.getLogger(CoursePaperServiceImpl.class);
    @Autowired
    private CoursePaperRepository coursePaperRepository;

    @Override
    public List<CoursePaperInfo> getCoursePaperList(CoursePaperQuery query) {
        Check.isNull(query, "查询参数不能为空！");
        Check.isEmpty(query.getOrgId(), "学校ID不能为空！");
        Check.isEmpty(query.getExamId(), "考试ID不能为空！");
        Check.isEmpty(query.getCourseId(), "课程ID不能为空！");

        //查询条件
        SearchBuilder searches = new SearchBuilder();
        searches.eq("orgId", query.getOrgId());
        searches.eq("examId", query.getExamId());
        searches.eq("courseId", query.getCourseId());
        Specification<CoursePaper> spec = SpecUtils.buildSearchers(CoursePaper.class, searches.build());
        List<CoursePaper> list = coursePaperRepository.findAll(spec);
        return CoursePaperConvert.ofList(list);
    }

    @Override
    public void syncCourseNameByCourseId(Long courseId, String courseName) {
        if (courseId == null || StringUtils.isBlank(courseName)) {
            return;
        }
        coursePaperRepository.updateCourseNameByCourseId(courseId, courseName);
    }

    @Override
    public File downloadPaperStructure(Long examId, Long paperId) {
        return null;
    }

    @Override
    public void checkPaperStructure(Long examId, Long paperId) {

    }

    @Override
    public void allotCoursePaper(Long orgId, Long examId) {

    }

    @Override
    public CoursePaperTotalInfo getPaperTotalByOrgIdAndExamId(Long orgId, Long examId) {
        return null;
    }

    @Override
    public File exportAllByOrgIdAndExamId(Long orgId, Long examId) {
        return null;
    }

    @Override
    public File exportBatchByIds(Long[] ids) {
        return null;
    }

}